# storeimg

[![image](https://img.shields.io/pypi/v/storeimg.svg)](https://python.org/pypi/storeimg)

Storeimg can check if the size of your image matches the Apple spec and whether the image has alpha before you upload the image to the App Store.


# Installation
1. Install on python2.7+

```
sudo pip install storeimg
```

2. use

```
storeimg file_path

```

